@@ -1,5 +1,5 @@
 #!/bin/sh
-# $Id: testminiwget.sh,v 1.18 2020/05/29 21:14:22 nanard Exp $
+# $Id: testminiwget.sh,v 1.19 2021/09/28 21:10:12 nanard Exp $
 # vim: tabstop=4 shiftwidth=4 noexpandtab
 # project miniupnp : http://miniupnp.free.fr/
 # (c) 2011-2019 Thomas Bernard
@@ -17,6 +17,8 @@
 # it should now also run with dash
 
 TMPD=`mktemp -d -t miniwgetXXXXXXXXXX`
+TESTSERVER=./build/minihttptestserver
+TESTMINIWGET=./build/testminiwget
 HTTPSERVEROUT="${TMPD}/httpserverout"
 EXPECTEDFILE="${TMPD}/expectedfile"
 DOWNLOADEDFILE="${TMPD}/downloadedfile"
@@ -50,11 +52,15 @@ case "$HAVE_IPV6" in
 
 esac
 
-#make minihttptestserver
-#make testminiwget
+if [ ! -x "$TESTSERVER" ] || [ ! -x "$TESTMINIWGET" ] ; then
+	echo "Please build $TESTSERVER and $TESTMINIWGET"
+	#make minihttptestserver
+	#make testminiwget
+	exit 1
+fi
 
 # launching the test HTTP server
-./minihttptestserver $SERVERARGS -e $EXPECTEDFILE > $HTTPSERVEROUT &
+$TESTSERVER $SERVERARGS -e $EXPECTEDFILE > $HTTPSERVEROUT &
 SERVERPID=$!
 while [ -z "$PORT" ]; do
 	sleep 1
@@ -74,7 +80,7 @@ URL3="http://$ADDR:$PORT/addcrap"
 URL4="http://$ADDR:$PORT/malformed"
 
 echo "standard test ..."
-./testminiwget $URL1 "${DOWNLOADEDFILE}.1"
+$TESTMINIWGET $URL1 "${DOWNLOADEDFILE}.1"
 if cmp $EXPECTEDFILE "${DOWNLOADEDFILE}.1" ; then
 	echo "ok"
 else
@@ -83,7 +89,7 @@ else
 fi
 
 echo "chunked transfert encoding test ..."
-./testminiwget $URL2 "${DOWNLOADEDFILE}.2"
+$TESTMINIWGET $URL2 "${DOWNLOADEDFILE}.2"
 if cmp $EXPECTEDFILE "${DOWNLOADEDFILE}.2" ; then
 	echo "ok"
 else
@@ -92,7 +98,7 @@ else
 fi
 
 echo "response too long test ..."
-./testminiwget $URL3 "${DOWNLOADEDFILE}.3"
+$TESTMINIWGET $URL3 "${DOWNLOADEDFILE}.3"
 if cmp $EXPECTEDFILE "${DOWNLOADEDFILE}.3" ; then
 	echo "ok"
 else
@@ -101,7 +107,7 @@ else
 fi
 
 echo "malformed response test ..."
-./testminiwget $URL4 "${DOWNLOADEDFILE}.4"
+$TESTMINIWGET $URL4 "${DOWNLOADEDFILE}.4"
 
 # kill the test HTTP server
 kill $SERVERPID
